import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { CodePipelineClientResolvedConfig } from "../CodePipelineClient";
/**
 * @internal
 */
export interface CodePipelineHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface CodePipelineHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<CodePipelineClientResolvedConfig, HandlerExecutionContext, CodePipelineHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultCodePipelineHttpAuthSchemeParametersProvider: (config: CodePipelineClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<CodePipelineHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface CodePipelineHttpAuthSchemeProvider extends HttpAuthSchemeProvider<CodePipelineHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultCodePipelineHttpAuthSchemeProvider: CodePipelineHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: CodePipelineHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: CodePipelineHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
